@@ -29,15 +29,19 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 """
 
-version_info = (3, 3, 3)
+version_info = (4, 2, 5)
 
 __version__ = '.'.join(map(str, version_info))
+__installer_version__ = __version__
+__title__ = 'Spyder'
+__author__ = 'Spyder Project Contributors and others'
 __license__ = __doc__
 __project_url__ = 'https://github.com/spyder-ide/spyder'
 __forum_url__   = 'https://groups.google.com/group/spyderlib'
-__trouble_url__ = __project_url__ + '/wiki/Troubleshooting-Guide-and-FAQ'
+__trouble_url__ = 'https://docs.spyder-ide.org/current/first-steps.html'
 __trouble_url_short__ = 'https://tinyurl.com/SpyderHelp'
 __website_url__ = 'https://www.spyder-ide.org/'
+__docs_url__ = 'https://docs.spyder-ide.org/'
 
 # Dear (Debian, RPM, ...) package makers, please feel free to customize the
 # following path to module's data (images) and translations:
@@ -46,8 +50,7 @@ DOCPATH = '/usr/local/share/doc/spyder/'
 
 import os
 # Directory of the current file
-__dir__ = os.path.dirname(os.path.abspath(__file__))
-
+__current_directory__ = os.path.dirname(os.path.abspath(__file__))
 
 def add_to_distribution(dist):
     """Add package to py2exe/cx_Freeze distribution object
@@ -75,7 +78,8 @@ def get_versions(reporev=True):
     revision = None
     if reporev:
         from spyder.utils import vcs
-        revision, branch = vcs.get_git_revision(os.path.dirname(__dir__))
+        revision, branch = vcs.get_git_revision(
+            os.path.dirname(__current_directory__))
 
     if not sys.platform == 'darwin':  # To avoid a crash with our Mac app
         system = platform.system()
@@ -91,5 +95,6 @@ def get_versions(reporev=True):
         'qt_api_ver': qtpy.PYQT_VERSION,
         'system': system,   # Linux, Windows, ...
         'release': platform.release(),  # XP, 10.6, 2.2.0, etc.
-        'revision': revision,  # '9fdf926eccce'
+        'revision': revision,  # '9fdf926eccce',
+        'branch': branch,  # '4.x' or master
     }
